@@ -885,7 +885,7 @@ create_component (ECalBackendContacts *cbc,
 	e_cal_component_set_icalcomponent (cal_comp, ical_comp);
 
 	/* Set uid */
-	d(g_message ("Creating UID: %s", uid));
+	d (g_message ("Creating UID: %s", uid));
 	e_cal_component_set_uid (cal_comp, uid);
 
 	/* Set all-day event's date from contact data */
@@ -1031,16 +1031,6 @@ e_cal_backend_contacts_get_backend_property (ECalBackendSync *backend,
 	return processed;
 }
 
-static void
-e_cal_backend_contacts_remove (ECalBackendSync *backend,
-                               EDataCal *cal,
-                               GCancellable *cancellable,
-                               GError **perror)
-{
-	/* WRITE ME */
-	g_propagate_error (perror, EDC_ERROR (PermissionDenied));
-}
-
 static void
 e_cal_backend_contacts_get_object (ECalBackendSync *backend,
                                    EDataCal *cal,
@@ -1078,18 +1068,18 @@ e_cal_backend_contacts_get_object (ECalBackendSync *backend,
 	if (record->comp_birthday && g_str_has_suffix (uid, BIRTHDAY_UID_EXT)) {
 		*object = e_cal_component_get_as_string (record->comp_birthday);
 
-		d(g_message ("Return birthday: %s", *object));
+		d (g_message ("Return birthday: %s", *object));
 		return;
 	}
 
 	if (record->comp_anniversary && g_str_has_suffix (uid, ANNIVERSARY_UID_EXT)) {
 		*object = e_cal_component_get_as_string (record->comp_anniversary);
 
-		d(g_message ("Return anniversary: %s", *object));
+		d (g_message ("Return anniversary: %s", *object));
 		return;
 	}
 
-	d(g_message ("Returning nothing for uid: %s", uid));
+	d (g_message ("Returning nothing for uid: %s", uid));
 
 	g_propagate_error (perror, EDC_ERROR (ObjectNotFound));
 }
@@ -1419,7 +1409,6 @@ e_cal_backend_contacts_class_init (ECalBackendContactsClass *class)
 
 	sync_class->get_backend_property_sync	= e_cal_backend_contacts_get_backend_property;
 	sync_class->open_sync			= e_cal_backend_contacts_open;
-	sync_class->remove_sync			= e_cal_backend_contacts_remove;
 	sync_class->create_objects_sync		= e_cal_backend_contacts_create_objects;
 	sync_class->receive_objects_sync	= e_cal_backend_contacts_receive_objects;
 	sync_class->send_objects_sync		= e_cal_backend_contacts_send_objects;
