@@ -21,11 +21,16 @@
  * Authors: Hans Petter Jansson <hpj@novell.com>
  */
 
+#if !defined (__LIBEDATASERVERUI_H_INSIDE__) && !defined (LIBEDATASERVERUI_COMPILATION)
+#error "Only <libedataserverui/libedataserverui.h> should be included directly."
+#endif
+
 #ifndef E_NAME_SELECTOR_ENTRY_H
 #define E_NAME_SELECTOR_ENTRY_H
 
 #include <gtk/gtk.h>
-#include <libebook/e-contact.h>
+#include <libebook/libebook.h>
+
 #include <libedataserverui/e-contact-store.h>
 #include <libedataserverui/e-destination-store.h>
 #include <libedataserverui/e-tree-model-generator.h>
@@ -49,15 +54,6 @@
 	(G_TYPE_INSTANCE_GET_CLASS \
 	((obj), E_TYPE_NAME_SELECTOR_ENTRY, ENameSelectorEntryClass))
 
-#define MINIMUM_QUERY_LENGTH "/apps/evolution/addressbook/completion/minimum_query_length"
-
-/**
- * FORCE_SHOW_ADDRESS:
- *
- * Since: 2.24
- **/
-#define FORCE_SHOW_ADDRESS   "/apps/evolution/addressbook/completion/show_address"
-
 G_BEGIN_DECLS
 
 typedef struct _ENameSelectorEntry ENameSelectorEntry;
@@ -80,7 +76,23 @@ struct _ENameSelectorEntryClass {
 
 GType		e_name_selector_entry_get_type	(void);
 ENameSelectorEntry *
-		e_name_selector_entry_new	(void);
+		e_name_selector_entry_new	(ESourceRegistry *registry);
+ESourceRegistry *
+		e_name_selector_entry_get_registry
+						(ENameSelectorEntry *name_selector_entry);
+void		e_name_selector_entry_set_registry
+						(ENameSelectorEntry *name_selector_entry,
+						 ESourceRegistry *registry);
+gint		e_name_selector_entry_get_minimum_query_length
+						(ENameSelectorEntry *name_selector_entry);
+void		e_name_selector_entry_set_minimum_query_length
+						(ENameSelectorEntry *name_selector_entry,
+						 gint length);
+gboolean	e_name_selector_entry_get_show_address
+						(ENameSelectorEntry *name_selector_entry);
+void		e_name_selector_entry_set_show_address
+						(ENameSelectorEntry *name_selector_entry,
+						 gboolean show);
 EContactStore *	e_name_selector_entry_peek_contact_store
 						(ENameSelectorEntry *name_selector_entry);
 void		e_name_selector_entry_set_contact_store
